# Instabot

Languages: [🇬🇧](/docs/en/README.md) [🇷🇺](/docs/ru/README.md) [🇮🇹](/docs/it/README.md) [🇺🇦](/docs/ukr/README.md)

[![Telegram Chat](https://img.shields.io/badge/chat%20on-Telegram-blue.svg)](https://t.me/instabotproject)
[![Build Status](https://travis-ci.org/instagrambot/instabot.svg?branch=master)](https://travis-ci.org/instagrambot/instabot)

![Instabot is better than other open-source bots!](/docs/img/tag%20instabot.png "Instabot is better than other open-source bots!")
